==> aliyun-python-sdk-amqp-open-1.1.1.tar.gz: aliyun-python-sdk-amqp-open-1.1.1/aliyunsdkamqp_open/request/v20191212/ListQueueConsumersRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkamqp_open.endpoint import endpoint_data

class ListQueueConsumersRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'amqp-open', '2019-12-12', 'ListQueueConsumers','onsproxy')
		self.set_method('GET')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_InstanceId(self):
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self,InstanceId):
		self.add_query_param('InstanceId',InstanceId)

	def get_NextToken(self):
		return self.get_query_params().get('NextToken')

	def set_NextToken(self,NextToken):
		self.add_query_param('NextToken',NextToken)

	def get_QueryCount(self):
		return self.get_query_params().get('QueryCount')

	def set_QueryCount(self,QueryCount):
		self.add_query_param('QueryCount',QueryCount)

	def get_VirtualHost(self):
		return self.get_query_params().get('VirtualHost')

	def set_VirtualHost(self,VirtualHost):
		self.add_query_param('VirtualHost',VirtualHost)

	def get_Queue(self):
		return self.get_query_params().get('Queue')

	def set_Queue(self,Queue):
		self.add_query_param('Queue',Queue)

==> aliyun-python-sdk-amqp-open-1.1.4.tar.gz: aliyun-python-sdk-amqp-open-1.1.4/aliyunsdkamqp_open/request/v20191212/ListQueueConsumersRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkamqp_open.endpoint import endpoint_data

class ListQueueConsumersRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'amqp-open', '2019-12-12', 'ListQueueConsumers','onsproxy')
		self.set_method('GET')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_InstanceId(self): # String
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self, InstanceId):  # String
		self.add_query_param('InstanceId', InstanceId)
	def get_NextToken(self): # String
		return self.get_query_params().get('NextToken')

	def set_NextToken(self, NextToken):  # String
		self.add_query_param('NextToken', NextToken)
	def get_QueryCount(self): # Integer
		return self.get_query_params().get('QueryCount')

	def set_QueryCount(self, QueryCount):  # Integer
		self.add_query_param('QueryCount', QueryCount)
	def get_VirtualHost(self): # String
		return self.get_query_params().get('VirtualHost')

	def set_VirtualHost(self, VirtualHost):  # String
		self.add_query_param('VirtualHost', VirtualHost)
	def get_Queue(self): # String
		return self.get_query_params().get('Queue')

	def set_Queue(self, Queue):  # String
		self.add_query_param('Queue', Queue)
